# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAKE_UPRIGHT_METADATA = Metadata(
    id="522244f0d58e1f0d0f3872b5729dcc10bc9de41f.boutiques",
    name="make_upright",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MakeUprightOutputs(typing.NamedTuple):
    """
    Output object returned when calling `make_upright(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_image: OutputPathType
    """Registered upright MRI image"""


def make_upright(
    input_image: InputPathType,
    output_image: InputPathType,
    transformation_map: InputPathType,
    runner: Runner | None = None,
) -> MakeUprightOutputs:
    """
    Registers MRI input to the left/right reversed version using mri_robust_register
    and making use of the half-way space, resulting in an upright, forward facing
    head position.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_image: Input MRI image file in .mgz format.
        output_image: Output MRI image file in .mgz format.
        transformation_map: Transformation map file in .lta format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MakeUprightOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAKE_UPRIGHT_METADATA)
    cargs = []
    cargs.append("make_upright")
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    cargs.append(execution.input_file(transformation_map))
    ret = MakeUprightOutputs(
        root=execution.output_file("."),
        registered_image=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAKE_UPRIGHT_METADATA",
    "MakeUprightOutputs",
    "make_upright",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_INTENSITY_PROFILE_METADATA = Metadata(
    id="4503435a83a78998ccb884fce0c0c30ed9f78d3b.boutiques",
    name="mris_intensity_profile",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisIntensityProfileOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_intensity_profile(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_curvature_file: OutputPathType
    """Curvature file with the intensity profile measurement."""
    output_mean_profile_integral: OutputPathType | None
    """File with the mean profile-integral."""


def mris_intensity_profile(
    subject_name: str,
    hemi: str,
    volume: InputPathType,
    output_file: str,
    write_surf: str | None = None,
    sdir: str | None = None,
    white: str | None = None,
    pial: str | None = None,
    normalize_flag: bool = False,
    mean: str | None = None,
    xform: InputPathType | None = None,
    src: InputPathType | None = None,
    dst: InputPathType | None = None,
    invert_flag: bool = False,
    runner: Runner | None = None,
) -> MrisIntensityProfileOutputs:
    """
    This program computes the intensity profile of the cortical ribbon and writes
    the resulting measurement into a 'curvature' file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemi: Hemisphere (e.g. lh or rh).
        volume: Volume file to be processed.
        output_file: Output file where the measurement is saved.
        write_surf: Write the variational pial surface target locations.
        sdir: Specifies the SUBJECTS_DIR.
        white: Specifies the WHITE surface filename.
        pial: Specifies the PIAL surface filename.
        normalize_flag: Normalized sampling with respect to thickness.
        mean: Outputs the mean profile-integral to the specified file (output\
            is in curv format).
        xform: Specify the registration transformation that maps the T1 volume\
            to the input volume to be sampled.
        src: Source volume used when computing the registration transformation.
        dst: Destination volume used when computing the registration\
            transformation.
        invert_flag: Apply the registration transformation inversely.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisIntensityProfileOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_INTENSITY_PROFILE_METADATA)
    cargs = []
    cargs.append("mris_intensity_profile")
    cargs.append(subject_name)
    cargs.append(hemi)
    cargs.append(execution.input_file(volume))
    cargs.append(output_file)
    if write_surf is not None:
        cargs.extend([
            "-write_surf",
            write_surf
        ])
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if white is not None:
        cargs.extend([
            "-white",
            white
        ])
    if pial is not None:
        cargs.extend([
            "-pial",
            pial
        ])
    if normalize_flag:
        cargs.append("-normalize")
    if mean is not None:
        cargs.extend([
            "-mean",
            mean
        ])
    if xform is not None:
        cargs.extend([
            "-xform",
            execution.input_file(xform)
        ])
    if src is not None:
        cargs.extend([
            "-src",
            execution.input_file(src)
        ])
    if dst is not None:
        cargs.extend([
            "-dst",
            execution.input_file(dst)
        ])
    if invert_flag:
        cargs.append("-invert")
    ret = MrisIntensityProfileOutputs(
        root=execution.output_file("."),
        output_curvature_file=execution.output_file(output_file),
        output_mean_profile_integral=execution.output_file(mean) if (mean is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_INTENSITY_PROFILE_METADATA",
    "MrisIntensityProfileOutputs",
    "mris_intensity_profile",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIRT_METADATA = Metadata(
    id="f6fc35e6267b771a9a40d8e09382a09e76789072.boutiques",
    name="flirt",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FlirtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flirt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Registered output file."""
    out_matrix_file: OutputPathType
    """Output affine matrix in 4x4 asciii format."""


def flirt(
    in_file: InputPathType,
    reference: InputPathType,
    out_file: str,
    out_matrix_file: str,
    angle_rep: typing.Literal["quaternion", "euler"] | None = None,
    apply_isoxfm: float | None = None,
    apply_xfm: bool = False,
    bbrslope: float | None = None,
    bbrtype: typing.Literal["signed", "global_abs", "local_abs"] | None = None,
    bgvalue: float | None = None,
    bins: int | None = None,
    coarse_search: int | None = None,
    cost: typing.Literal["mutualinfo", "corratio", "normcorr", "normmi", "leastsq", "labeldiff", "bbr"] | None = "corratio",
    cost_func: typing.Literal["mutualinfo", "corratio", "normcorr", "normmi", "leastsq", "labeldiff", "bbr"] | None = "corratio",
    datatype: typing.Literal["char", "short", "int", "float", "double"] | None = None,
    display_init: bool = False,
    dof: int | None = 12,
    echospacing: float | None = None,
    fieldmap: InputPathType | None = None,
    fieldmapmask: InputPathType | None = None,
    fine_search: int | None = None,
    force_scaling: bool = False,
    in_matrix_file: InputPathType | None = None,
    in_weight: InputPathType | None = None,
    interp: typing.Literal["trilinear", "nearestneighbour", "sinc", "spline"] | None = "trilinear",
    min_sampling: float | None = None,
    no_clamp: bool = False,
    no_resample: bool = False,
    no_resample_blur: bool = False,
    no_search: bool = False,
    padding_size: int | None = None,
    pedir: int | None = None,
    ref_weight: InputPathType | None = None,
    rigid2_d: bool = False,
    schedule: InputPathType | None = None,
    searchr_x: list[int] | None = None,
    searchr_y: list[int] | None = None,
    searchr_z: list[int] | None = None,
    sinc_width: int | None = None,
    sinc_window: typing.Literal["rectangular", "hanning", "blackman"] | None = None,
    uses_qform: bool = False,
    verbose: int | None = None,
    wm_seg: InputPathType | None = None,
    wmcoords: InputPathType | None = None,
    wmnorms: InputPathType | None = None,
    runner: Runner | None = None,
) -> FlirtOutputs:
    """
    FLIRT (FMRIB's Linear Image Registration Tool) is a fully automated robust and
    accurate tool for linear (affine) intra- and inter-modal brain image
    registration.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        in_file: Input file.
        reference: Reference file.
        out_file: Registered output file.
        out_matrix_file: Output affine matrix in 4x4 asciii format.
        angle_rep: 'quaternion' or 'euler'. Representation of rotation angles.
        apply_isoxfm: As applyxfm but forces isotropic resampling.
        apply_xfm: Apply transformation supplied by in_matrix_file or\
            uses_qform to use the affine matrix stored in the reference header.
        bbrslope: Value of bbr slope.
        bbrtype: 'signed' or 'global_abs' or 'local_abs'. Type of bbr cost\
            function: signed [default], global_abs, local_abs.
        bgvalue: Use specified background value for points outside fov.
        bins: Number of histogram bins.
        coarse_search: Coarse search delta angle.
        cost: 'mutualinfo' or 'corratio' or 'normcorr' or 'normmi' or 'leastsq'\
            or 'labeldiff' or 'bbr'. Cost function.
        cost_func: 'mutualinfo' or 'corratio' or 'normcorr' or 'normmi' or\
            'leastsq' or 'labeldiff' or 'bbr'. Cost function.
        datatype: 'char' or 'short' or 'int' or 'float' or 'double'. Force\
            output data type.
        display_init: Display initial matrix.
        dof: Number of transform degrees of freedom.
        echospacing: Value of epi echo spacing - units of seconds.
        fieldmap: Fieldmap image in rads/s - must be already registered to the\
            reference image.
        fieldmapmask: Mask for fieldmap image.
        fine_search: Fine search delta angle.
        force_scaling: Force rescaling even for low-res images.
        in_matrix_file: Input 4x4 affine matrix.
        in_weight: File for input weighting volume.
        interp: 'trilinear' or 'nearestneighbour' or 'sinc' or 'spline'. Final\
            interpolation method used in reslicing.
        min_sampling: Set minimum voxel dimension for sampling.
        no_clamp: Do not use intensity clamping.
        no_resample: Do not change input sampling.
        no_resample_blur: Do not use blurring on downsampling.
        no_search: Set all angular searches to ranges 0 to 0.
        padding_size: For applyxfm: interpolates outside image by size.
        pedir: Phase encode direction of epi - 1/2/3=x/y/z & -1/-2/-3=-x/-y/-z.
        ref_weight: File for reference weighting volume.
        rigid2_d: Use 2d rigid body mode - ignores dof.
        schedule: Replaces default schedule.
        searchr_x: Search angles along x-axis, in degrees.
        searchr_y: Search angles along y-axis, in degrees.
        searchr_z: Search angles along z-axis, in degrees.
        sinc_width: Full-width in voxels.
        sinc_window: 'rectangular' or 'hanning' or 'blackman'. Sinc window.
        uses_qform: Initialize using sform or qform.
        verbose: Verbose mode, 0 is least.
        wm_seg: White matter segmentation volume needed by bbr cost function.
        wmcoords: White matter boundary coordinates for bbr cost function.
        wmnorms: White matter boundary normals for bbr cost function.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlirtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIRT_METADATA)
    cargs = []
    cargs.append("flirt")
    cargs.extend([
        "-in",
        execution.input_file(in_file)
    ])
    cargs.extend([
        "-ref",
        execution.input_file(reference)
    ])
    cargs.extend([
        "-out",
        out_file
    ])
    cargs.extend([
        "-omat",
        out_matrix_file
    ])
    if angle_rep is not None:
        cargs.extend([
            "-anglerep",
            angle_rep
        ])
    if apply_isoxfm is not None:
        cargs.extend([
            "-applyisoxfm",
            str(apply_isoxfm)
        ])
    if apply_xfm:
        cargs.append("-applyxfm")
    if bbrslope is not None:
        cargs.extend([
            "-bbrslope",
            str(bbrslope)
        ])
    if bbrtype is not None:
        cargs.extend([
            "-bbrtype",
            bbrtype
        ])
    if bgvalue is not None:
        cargs.extend([
            "-setbackground",
            str(bgvalue)
        ])
    if bins is not None:
        cargs.extend([
            "-bins",
            str(bins)
        ])
    if coarse_search is not None:
        cargs.extend([
            "-coarsesearch",
            str(coarse_search)
        ])
    if cost is not None:
        cargs.extend([
            "-cost",
            cost
        ])
    if cost_func is not None:
        cargs.extend([
            "-searchcost",
            cost_func
        ])
    if datatype is not None:
        cargs.extend([
            "-datatype",
            datatype
        ])
    if display_init:
        cargs.append("-displayinit")
    if dof is not None:
        cargs.extend([
            "-dof",
            str(dof)
        ])
    if echospacing is not None:
        cargs.extend([
            "-echospacing",
            str(echospacing)
        ])
    if fieldmap is not None:
        cargs.extend([
            "-fieldmap",
            execution.input_file(fieldmap)
        ])
    if fieldmapmask is not None:
        cargs.extend([
            "-fieldmapmask",
            execution.input_file(fieldmapmask)
        ])
    if fine_search is not None:
        cargs.extend([
            "-finesearch",
            str(fine_search)
        ])
    if force_scaling:
        cargs.append("-forcescaling")
    if in_matrix_file is not None:
        cargs.extend([
            "-init",
            execution.input_file(in_matrix_file)
        ])
    if in_weight is not None:
        cargs.extend([
            "-inweight",
            execution.input_file(in_weight)
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if min_sampling is not None:
        cargs.extend([
            "-minsampling",
            str(min_sampling)
        ])
    if no_clamp:
        cargs.append("-noclamp")
    if no_resample:
        cargs.append("-noresample")
    if no_resample_blur:
        cargs.append("-noresampblur")
    if no_search:
        cargs.append("-nosearch")
    if padding_size is not None:
        cargs.extend([
            "-paddingsize",
            str(padding_size)
        ])
    if pedir is not None:
        cargs.extend([
            "-pedir",
            str(pedir)
        ])
    if ref_weight is not None:
        cargs.extend([
            "-refweight",
            execution.input_file(ref_weight)
        ])
    if rigid2_d:
        cargs.append("-2D")
    if schedule is not None:
        cargs.extend([
            "-schedule",
            execution.input_file(schedule)
        ])
    if searchr_x is not None:
        cargs.extend([
            "-searchrx",
            *map(str, searchr_x)
        ])
    if searchr_y is not None:
        cargs.extend([
            "-searchry",
            *map(str, searchr_y)
        ])
    if searchr_z is not None:
        cargs.extend([
            "-searchrz",
            *map(str, searchr_z)
        ])
    if sinc_width is not None:
        cargs.extend([
            "-sincwidth",
            str(sinc_width)
        ])
    if sinc_window is not None:
        cargs.extend([
            "-sincwindow",
            sinc_window
        ])
    if uses_qform:
        cargs.append("-usesqform")
    if verbose is not None:
        cargs.extend([
            "-verbose",
            str(verbose)
        ])
    if wm_seg is not None:
        cargs.extend([
            "-wmseg",
            execution.input_file(wm_seg)
        ])
    if wmcoords is not None:
        cargs.extend([
            "-wmcoords",
            execution.input_file(wmcoords)
        ])
    if wmnorms is not None:
        cargs.extend([
            "-wmnorms",
            execution.input_file(wmnorms)
        ])
    ret = FlirtOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(out_file),
        out_matrix_file=execution.output_file(out_matrix_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIRT_METADATA",
    "FlirtOutputs",
    "flirt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SETUP_GROUP_IN_CORR_METADATA = Metadata(
    id="de29e68b50548580e79210d656042b141dbd77c7.boutiques",
    name="3dSetupGroupInCorr",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSetupGroupInCorrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_setup_group_in_corr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    niml_file: OutputPathType
    """Text file containing the header information describing the data file."""
    data_file: OutputPathType
    """Data file containing all the time series from all the datasets."""


def v_3d_setup_group_in_corr(
    datasets: list[InputPathType],
    prefix: str,
    mask_dataset: InputPathType | None = None,
    short_flag: bool = False,
    byte_flag: bool = False,
    labels_file: InputPathType | None = None,
    delete_flag: bool = False,
    prep_method: str | None = None,
    lr_pairs: list[str] | None = None,
    runner: Runner | None = None,
) -> V3dSetupGroupInCorrOutputs:
    """
    Pre-process a collection of AFNI 3D+time datasets for use with Group InstaCorr.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: AFNI 3D+time datasets to be processed.
        prefix: Prefix for output dataset names.
        mask_dataset: Mask dataset for voxel selection.
        short_flag: Store data as 16-bit shorts.
        byte_flag: Store data as 8-bit bytes.
        labels_file: File containing a list of labels for each dataset.
        delete_flag: Delete input datasets from disk after processing.
        prep_method: Preprocess each data time series with the specified\
            method.
        lr_pairs: Set the domains for left and right hemisphere surfaces and\
            indicate that the datasets are arranged in (Left, Right) pairs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSetupGroupInCorrOutputs`).
    """
    if lr_pairs is not None and not (len(lr_pairs) <= 2): 
        raise ValueError(f"Length of 'lr_pairs' must be less than 2 but was {len(lr_pairs)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SETUP_GROUP_IN_CORR_METADATA)
    cargs = []
    cargs.append("3dSetupGroupInCorr")
    cargs.extend([execution.input_file(f) for f in datasets])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if short_flag:
        cargs.append("-short")
    if byte_flag:
        cargs.append("-byte")
    if labels_file is not None:
        cargs.extend([
            "-labels",
            execution.input_file(labels_file)
        ])
    if delete_flag:
        cargs.append("-DELETE")
    if prep_method is not None:
        cargs.extend([
            "-prep",
            prep_method
        ])
    if lr_pairs is not None:
        cargs.extend([
            "-LRpairs",
            *lr_pairs
        ])
    ret = V3dSetupGroupInCorrOutputs(
        root=execution.output_file("."),
        niml_file=execution.output_file(prefix + ".grpincorr.niml"),
        data_file=execution.output_file(prefix + ".grpincorr.data"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSetupGroupInCorrOutputs",
    "V_3D_SETUP_GROUP_IN_CORR_METADATA",
    "v_3d_setup_group_in_corr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AVI2TALXFM_METADATA = Metadata(
    id="8aeaf0bd3a7339f6d2f2be8c9e4153a86e47e03a.boutiques",
    name="avi2talxfm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Avi2talxfmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `avi2talxfm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_xfm_file: OutputPathType
    """Resulting MNI transform file"""


def avi2talxfm(
    input_volume: InputPathType,
    target_volume: InputPathType,
    vox2vox_transform: InputPathType,
    output_xfm: str,
    runner: Runner | None = None,
) -> Avi2talxfmOutputs:
    """
    Convert voxel-to-voxel transform to MNI transform.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        target_volume: Target volume file.
        vox2vox_transform: Voxel-to-voxel transform file.
        output_xfm: Output MNI transform file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Avi2talxfmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AVI2TALXFM_METADATA)
    cargs = []
    cargs.append("avi2talxfm")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(target_volume))
    cargs.append(execution.input_file(vox2vox_transform))
    cargs.append(output_xfm)
    ret = Avi2talxfmOutputs(
        root=execution.output_file("."),
        output_xfm_file=execution.output_file(output_xfm),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AVI2TALXFM_METADATA",
    "Avi2talxfmOutputs",
    "avi2talxfm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GEN_SS_REVIEW_SCRIPTS_METADATA = Metadata(
    id="0b2bced52ccd788df5199b4d3c54d3385072af7d.boutiques",
    name="gen_ss_review_scripts",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class GenSsReviewScriptsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gen_ss_review_scripts(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    basic_review: OutputPathType
    """Basic review script output"""
    driver_review: OutputPathType
    """Driver review script output"""
    driver_commands: OutputPathType
    """Driver commands script output"""


def gen_ss_review_scripts(
    subject_id: str | None = None,
    rm_trs: float | None = None,
    num_stim: float | None = None,
    mb_level: float | None = None,
    slice_pattern: str | None = None,
    motion_dset: InputPathType | None = None,
    outlier_dset: InputPathType | None = None,
    enorm_dset: InputPathType | None = None,
    mot_limit: float | None = None,
    out_limit: float | None = None,
    xmat_regress: InputPathType | None = None,
    xmat_uncensored: InputPathType | None = None,
    stats_dset: InputPathType | None = None,
    final_anat: InputPathType | None = None,
    final_view: str | None = None,
    prefix: str | None = None,
    verbosity: float | None = None,
    uvars_json: InputPathType | None = None,
    init_uvars_json: InputPathType | None = None,
    runner: Runner | None = None,
) -> GenSsReviewScriptsOutputs:
    """
    Generate single subject analysis review scripts.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        subject_id: Subject ID.
        rm_trs: Number of TRs removed per run.
        num_stim: Number of main stimulus classes.
        mb_level: Multiband slice acquisition level (>= 1).
        slice_pattern: Slice timing pattern.
        motion_dset: Motion parameters dataset.
        outlier_dset: Outlier fraction time series dataset.
        enorm_dset: Euclidean norm of motion parameters dataset.
        mot_limit: Motion limit.
        out_limit: Outlier fraction limit.
        xmat_regress: X-matrix file used in regression.
        xmat_uncensored: Un-censored X-matrix file.
        stats_dset: Output from 3dDeconvolve.
        final_anat: Final anatomical dataset.
        final_view: Final view of data (e.g. 'orig' or 'tlrc').
        prefix: Set the prefix for script names.
        verbosity: Set the verbosity level.
        uvars_json: Write JSON file of user variables dict.
        init_uvars_json: Initialize user variables from the given JSON file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GenSsReviewScriptsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GEN_SS_REVIEW_SCRIPTS_METADATA)
    cargs = []
    cargs.append("gen_ss_review_scripts.py")
    if subject_id is not None:
        cargs.extend([
            "-subj",
            subject_id
        ])
    if rm_trs is not None:
        cargs.extend([
            "-rm_trs",
            str(rm_trs)
        ])
    if num_stim is not None:
        cargs.extend([
            "-num_stim",
            str(num_stim)
        ])
    if mb_level is not None:
        cargs.extend([
            "-mb_level",
            str(mb_level)
        ])
    if slice_pattern is not None:
        cargs.extend([
            "-slice_pattern",
            slice_pattern
        ])
    if motion_dset is not None:
        cargs.extend([
            "-motion_dset",
            execution.input_file(motion_dset)
        ])
    if outlier_dset is not None:
        cargs.extend([
            "-outlier_dset",
            execution.input_file(outlier_dset)
        ])
    if enorm_dset is not None:
        cargs.extend([
            "-enorm_dset",
            execution.input_file(enorm_dset)
        ])
    if mot_limit is not None:
        cargs.extend([
            "-mot_limit",
            str(mot_limit)
        ])
    if out_limit is not None:
        cargs.extend([
            "-out_limit",
            str(out_limit)
        ])
    if xmat_regress is not None:
        cargs.extend([
            "-xmat_regress",
            execution.input_file(xmat_regress)
        ])
    if xmat_uncensored is not None:
        cargs.extend([
            "-xmat_uncensored",
            execution.input_file(xmat_uncensored)
        ])
    if stats_dset is not None:
        cargs.extend([
            "-stats_dset",
            execution.input_file(stats_dset)
        ])
    if final_anat is not None:
        cargs.extend([
            "-final_anat",
            execution.input_file(final_anat)
        ])
    if final_view is not None:
        cargs.extend([
            "-final_view",
            final_view
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    if uvars_json is not None:
        cargs.extend([
            "-write_uvars_json",
            execution.input_file(uvars_json)
        ])
    if init_uvars_json is not None:
        cargs.extend([
            "-init_uvars_json",
            execution.input_file(init_uvars_json)
        ])
    ret = GenSsReviewScriptsOutputs(
        root=execution.output_file("."),
        basic_review=execution.output_file("./@ss_review_basic"),
        driver_review=execution.output_file("./@ss_review_driver"),
        driver_commands=execution.output_file("./@ss_review_driver_commands"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GEN_SS_REVIEW_SCRIPTS_METADATA",
    "GenSsReviewScriptsOutputs",
    "gen_ss_review_scripts",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_JOINT_DENSITY_METADATA = Metadata(
    id="95c3248976aa45e74859871185ad767414270ee1.boutiques",
    name="mri_joint_density",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriJointDensityOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_joint_density(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file containing the computed joint density"""


def mri_joint_density(
    vol1: InputPathType,
    vol2: InputPathType,
    output_density_file: str,
    runner: Runner | None = None,
) -> MriJointDensityOutputs:
    """
    Tool for computing joint density from two volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vol1: First input volume.
        vol2: Second input volume.
        output_density_file: Output joint density file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriJointDensityOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_JOINT_DENSITY_METADATA)
    cargs = []
    cargs.append("mri_joint_density")
    cargs.append(execution.input_file(vol1))
    cargs.append(execution.input_file(vol2))
    cargs.append(output_density_file)
    ret = MriJointDensityOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_density_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_JOINT_DENSITY_METADATA",
    "MriJointDensityOutputs",
    "mri_joint_density",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GDCMCONV_FS_METADATA = Metadata(
    id="c4cb69979a329deef98f15b2e797b9c57375a6ef.boutiques",
    name="gdcmconv.fs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GdcmconvFsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gdcmconv_fs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gdcmconv_fs(
    input_file: InputPathType,
    output_file: str,
    explicit_flag: bool = False,
    implicit_flag: bool = False,
    use_dict_flag: bool = False,
    with_private_dict_flag: bool = False,
    check_meta_flag: bool = False,
    root_uid: str | None = None,
    remove_gl_flag: bool = False,
    remove_private_tags_flag: bool = False,
    remove_retired_flag: bool = False,
    apply_lut_flag: bool = False,
    photometric_interpretation: str | None = None,
    raw_flag: bool = False,
    deflated_flag: bool = False,
    jpeg_flag: bool = False,
    j2k_flag: bool = False,
    jpegls_flag: bool = False,
    rle_flag: bool = False,
    force_flag: bool = False,
    generate_icon_flag: bool = False,
    icon_minmax: list[float] | None = None,
    icon_auto_minmax_flag: bool = False,
    compress_icon_flag: bool = False,
    planar_configuration: str | None = None,
    lossy_flag: bool = False,
    split: float | None = None,
    verbose_flag: bool = False,
    warning_flag: bool = False,
    debug_flag: bool = False,
    error_flag: bool = False,
    quiet_flag: bool = False,
    jpeg_quality: float | None = None,
    lossy_error: int | None = None,
    rate: float | None = None,
    j2k_quality: float | None = None,
    tile: list[float] | None = None,
    number_resolution: float | None = None,
    irreversible_flag: bool = False,
    ignore_errors_flag: bool = False,
    runner: Runner | None = None,
) -> GdcmconvFsOutputs:
    """
    Convert a DICOM file into another DICOM file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input DICOM filename.
        output_file: Output DICOM filename.
        explicit_flag: Change Transfer Syntax to explicit.
        implicit_flag: Change Transfer Syntax to implicit.
        use_dict_flag: Use dict for VR (only public by default).
        with_private_dict_flag: Use private dict for VR (advanced user only).
        check_meta_flag: Check File Meta Information (advanced user only).
        root_uid: Root UID.
        remove_gl_flag: Remove group length (deprecated in DICOM 2008).
        remove_private_tags_flag: Remove private tags.
        remove_retired_flag: Remove retired tags.
        apply_lut_flag: Apply LUT (non-standard, advanced user only).
        photometric_interpretation: Change Photometric Interpretation (when\
            possible).
        raw_flag: Decompress image.
        deflated_flag: Compress using deflated (gzip).
        jpeg_flag: Compress image in jpeg.
        j2k_flag: Compress image in j2k.
        jpegls_flag: Compress image in jpeg-ls.
        rle_flag: Compress image in rle (lossless only).
        force_flag: Force decompression/merging before recompression/splitting.
        generate_icon_flag: Generate icon.
        icon_minmax: Min/Max value for icon.
        icon_auto_minmax_flag: Automatically compute best Min/Max values for\
            icon.
        compress_icon_flag: Decide whether icon follows main Transfer Syntax or\
            remains uncompressed.
        planar_configuration: Change planar configuration.
        lossy_flag: Use the lossy (if possible) compressor.
        split: Write 2D image with multiple fragments (using max size).
        verbose_flag: More verbose (warning+error).
        warning_flag: Print warning info.
        debug_flag: Print debug info.
        error_flag: Print error info.
        quiet_flag: Do not print to stdout.
        jpeg_quality: Set JPEG quality.
        lossy_error: Set JPEG-LS lossy error.
        rate: Set J2K rate.
        j2k_quality: Set J2K quality.
        tile: Set J2K tile size.
        number_resolution: Set number of resolution.
        irreversible_flag: Set irreversible.
        ignore_errors_flag: Convert even if file is corrupted (advanced users\
            only, see disclaimers).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GdcmconvFsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GDCMCONV_FS_METADATA)
    cargs = []
    cargs.append("gdcmconv")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if explicit_flag:
        cargs.append("-X")
    if implicit_flag:
        cargs.append("-M")
    if use_dict_flag:
        cargs.append("-U")
    if with_private_dict_flag:
        cargs.append("--with-private-dict")
    if check_meta_flag:
        cargs.append("-C")
    if root_uid is not None:
        cargs.extend([
            "--root-uid",
            root_uid
        ])
    if remove_gl_flag:
        cargs.append("--remove-gl")
    if remove_private_tags_flag:
        cargs.append("--remove-private-tags")
    if remove_retired_flag:
        cargs.append("--remove-retired")
    if apply_lut_flag:
        cargs.append("-l")
    if photometric_interpretation is not None:
        cargs.extend([
            "-P",
            photometric_interpretation
        ])
    if raw_flag:
        cargs.append("-w")
    if deflated_flag:
        cargs.append("-d")
    if jpeg_flag:
        cargs.append("-J")
    if j2k_flag:
        cargs.append("-K")
    if jpegls_flag:
        cargs.append("-L")
    if rle_flag:
        cargs.append("-R")
    if force_flag:
        cargs.append("-F")
    if generate_icon_flag:
        cargs.append("--generate-icon")
    if icon_minmax is not None:
        cargs.extend([
            "--icon-minmax",
            *map(str, icon_minmax)
        ])
    if icon_auto_minmax_flag:
        cargs.append("--icon-auto-minmax")
    if compress_icon_flag:
        cargs.append("--compress-icon")
    if planar_configuration is not None:
        cargs.extend([
            "--planar-configuration",
            planar_configuration
        ])
    if lossy_flag:
        cargs.append("-Y")
    if split is not None:
        cargs.extend([
            "-S",
            str(split)
        ])
    if verbose_flag:
        cargs.append("-V")
    if warning_flag:
        cargs.append("-W")
    if debug_flag:
        cargs.append("-D")
    if error_flag:
        cargs.append("-E")
    if quiet_flag:
        cargs.append("--quiet")
    if jpeg_quality is not None:
        cargs.extend([
            "-q",
            str(jpeg_quality)
        ])
    if lossy_error is not None:
        cargs.extend([
            "-e",
            str(lossy_error)
        ])
    if rate is not None:
        cargs.extend([
            "-r",
            str(rate)
        ])
    if j2k_quality is not None:
        cargs.extend([
            "-q",
            str(j2k_quality)
        ])
    if tile is not None:
        cargs.extend([
            "-t",
            *map(str, tile)
        ])
    if number_resolution is not None:
        cargs.extend([
            "-n",
            str(number_resolution)
        ])
    if irreversible_flag:
        cargs.append("--irreversible")
    if ignore_errors_flag:
        cargs.append("-I")
    ret = GdcmconvFsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GDCMCONV_FS_METADATA",
    "GdcmconvFsOutputs",
    "gdcmconv_fs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DO_EXAMPLES_METADATA = Metadata(
    id="a9216d6bc30f6cf096b83a22a6cc899b517e504e.boutiques",
    name="@DO.examples",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDoExamplesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__do_examples(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_log: OutputPathType
    """Output log file when running in auto test mode"""


def v__do_examples(
    auto_test: bool = False,
    runner: Runner | None = None,
) -> VDoExamplesOutputs:
    """
    A script to illustrate the use of Displayable Objects in SUMA.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        auto_test: Run this script in test mode where user prompts are timed\
            out at 2 seconds, and the command output log is preserved in a file\
            called __testlog.txt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDoExamplesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DO_EXAMPLES_METADATA)
    cargs = []
    cargs.append("@DO.examples")
    if auto_test:
        cargs.append("-auto_test")
    ret = VDoExamplesOutputs(
        root=execution.output_file("."),
        output_log=execution.output_file("__testlog.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDoExamplesOutputs",
    "V__DO_EXAMPLES_METADATA",
    "v__do_examples",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPUTE_VOLUME_FRACTIONS_METADATA = Metadata(
    id="0166823a396772941b111de738d47982e374ec28.boutiques",
    name="mri_compute_volume_fractions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriComputeVolumeFractionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compute_volume_fractions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_cortex: OutputPathType
    """Output cortex volume file."""
    output_subcort_gm: OutputPathType
    """Output subcortical gray matter volume file."""
    output_wm: OutputPathType
    """Output white matter volume file."""
    output_csf: OutputPathType
    """Output cerebrospinal fluid volume file."""


def mri_compute_volume_fractions(
    output_stem: str,
    registration_file: InputPathType | None = None,
    regheader: str | None = None,
    usf: float | None = None,
    resolution: float | None = None,
    resmm: float | None = None,
    segmentation_file: InputPathType | None = None,
    wsurf: str | None = None,
    psurf: str | None = None,
    no_aseg: bool = False,
    stackfile: str | None = None,
    gmfile: str | None = None,
    no_fill_csf: bool = False,
    dilation: float | None = None,
    out_seg: str | None = None,
    ttseg: str | None = None,
    ttseg_ctab: str | None = None,
    mgz_format: bool = False,
    mgh_format: bool = False,
    nii_format: bool = False,
    nii_gz_format: bool = False,
    ttype_head: bool = False,
    vg_thresh: float | None = None,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriComputeVolumeFractionsOutputs:
    """
    Computes partial volume fractions for cortex, subcortical GM, WM and CSF.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_stem: Output stem for generated files (e.g. cortex, subcort_gm,\
            wm, csf). Files will be saved with this stem in different formats based\
            on the selected flags.
        registration_file: Registration file (can be LTA or reg.dat). If using\
            reg.dat, a template volume is needed.
        regheader: Specify the subject for regheader.
        usf: Set anatomical upsample factor (default is 2).
        resolution: Resolution setting. Sets USF to round(1/res).
        resmm: Set functional upsampling resolution (default is\
            aseg->xsize/(USF)).
        segmentation_file: Use specified segmentation file instead of aseg.mgz.
        wsurf: Specify the white surface (default is 'white').
        psurf: Specify the pial surface (default is 'pial').
        no_aseg: Do not include aseg in processing (useful for testing).
        stackfile: Put cortex, subcortical GM, WM, CSF into a single\
            multi-frame file.
        gmfile: Put cortex + subcortical GM into a single-frame file.
        no_fill_csf: Do not attempt to fill voxels surrounding segmentation\
            with extracerebral CSF segmentation.
        dilation: For xCSF fill, dilate by specified number (default is 3). Use\
            -1 to fill the entire volume.
        out_seg: Save segmentation (after adding xCSF voxels).
        ttseg: Save tissue type segmentation.
        ttseg_ctab: Save tissue type segmentation color table.
        mgz_format: Use MGZ format.
        mgh_format: Use MGH format.
        nii_format: Use NII format.
        nii_gz_format: Use NII.GZ format.
        ttype_head: Use default+head instead of default tissue type info for\
            segmentation.
        vg_thresh: Threshold for 'ERROR: LTAconcat(): LTAs 0 and 1 do not\
            match'.
        debug: Turn on debugging mode.
        checkopts: Do not run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriComputeVolumeFractionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPUTE_VOLUME_FRACTIONS_METADATA)
    cargs = []
    cargs.append("mri_compute_volume_fractions")
    cargs.extend([
        "--o",
        output_stem
    ])
    if registration_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(registration_file)
        ])
    if regheader is not None:
        cargs.extend([
            "--regheader",
            regheader
        ])
    if usf is not None:
        cargs.extend([
            "--usf",
            str(usf)
        ])
    if resolution is not None:
        cargs.extend([
            "--r",
            str(resolution)
        ])
    if resmm is not None:
        cargs.extend([
            "--resmm",
            str(resmm)
        ])
    if segmentation_file is not None:
        cargs.extend([
            "--seg",
            execution.input_file(segmentation_file)
        ])
    if wsurf is not None:
        cargs.extend([
            "--wsurf",
            wsurf
        ])
    if psurf is not None:
        cargs.extend([
            "--psurf",
            psurf
        ])
    if no_aseg:
        cargs.append("--no-aseg")
    if stackfile is not None:
        cargs.extend([
            "--stack",
            stackfile
        ])
    if gmfile is not None:
        cargs.extend([
            "--gm",
            gmfile
        ])
    if no_fill_csf:
        cargs.append("--no-fill-csf")
    if dilation is not None:
        cargs.extend([
            "--dil",
            str(dilation)
        ])
    if out_seg is not None:
        cargs.extend([
            "--out-seg",
            out_seg
        ])
    if ttseg is not None:
        cargs.extend([
            "--ttseg",
            ttseg
        ])
    if ttseg_ctab is not None:
        cargs.extend([
            "--ttseg-ctab",
            ttseg_ctab
        ])
    if mgz_format:
        cargs.append("--mgz")
    if mgh_format:
        cargs.append("--mgh")
    if nii_format:
        cargs.append("--nii")
    if nii_gz_format:
        cargs.append("--nii.gz")
    if ttype_head:
        cargs.append("--ttype+head")
    if vg_thresh is not None:
        cargs.extend([
            "--vg-thresh",
            str(vg_thresh)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriComputeVolumeFractionsOutputs(
        root=execution.output_file("."),
        output_cortex=execution.output_file(output_stem + ".cortex.mgz"),
        output_subcort_gm=execution.output_file(output_stem + ".subcort_gm.mgz"),
        output_wm=execution.output_file(output_stem + ".wm.mgz"),
        output_csf=execution.output_file(output_stem + ".csf.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPUTE_VOLUME_FRACTIONS_METADATA",
    "MriComputeVolumeFractionsOutputs",
    "mri_compute_volume_fractions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_SYSTEM_CHECK_PY_METADATA = Metadata(
    id="707dd8a3faf114c94899a8373ea46705cdf40480.boutiques",
    name="afni_system_check.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniSystemCheckPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_system_check_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_system_check_py(
    check_all: bool = False,
    find_prog: str | None = None,
    exact: str | None = None,
    disp_num_cpu: bool = False,
    disp_ver_matplotlib: bool = False,
    dot_file_list: bool = False,
    dot_file_show: bool = False,
    dot_file_pack: str | None = None,
    casematch: str | None = None,
    data_root: str | None = None,
    runner: Runner | None = None,
) -> AfniSystemCheckPyOutputs:
    """
    Perform various system checks for figuring out AFNI installation issues.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        check_all: Perform all system checks.
        find_prog: Search PATH for PROG.
        exact: Search for PROG without wildcards in -find_prog.
        disp_num_cpu: Display number of CPUs available.
        disp_ver_matplotlib: Display matplotlib version (else 'None').
        dot_file_list: List all found dot files (startup files).
        dot_file_show: Display contents of all found dot files.
        dot_file_pack: Create a NAME.tgz package containing dot files.
        casematch: Match case in -find_prog.
        data_root: Search for class data under DDIR.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniSystemCheckPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_SYSTEM_CHECK_PY_METADATA)
    cargs = []
    cargs.append("afni_system_check.py")
    if check_all:
        cargs.append("-check_all")
    if find_prog is not None:
        cargs.extend([
            "-find_prog",
            find_prog
        ])
    if exact is not None:
        cargs.extend([
            "-exact",
            exact
        ])
    if disp_num_cpu:
        cargs.append("-disp_num_cpu")
    if disp_ver_matplotlib:
        cargs.append("-disp_ver_matplotlib")
    if dot_file_list:
        cargs.append("-dot_file_list")
    if dot_file_show:
        cargs.append("-dot_file_show")
    if dot_file_pack is not None:
        cargs.extend([
            "-dot_file_pack",
            dot_file_pack
        ])
    if casematch is not None:
        cargs.extend([
            "-casematch",
            casematch
        ])
    if data_root is not None:
        cargs.extend([
            "-data_root",
            data_root
        ])
    ret = AfniSystemCheckPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_SYSTEM_CHECK_PY_METADATA",
    "AfniSystemCheckPyOutputs",
    "afni_system_check_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_PROBE_IMA_METADATA = Metadata(
    id="4d25ff07c5364e2ed4ab09e6c6aea4ca9d6b1dd1.boutiques",
    name="mri_probe_ima",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriProbeImaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_probe_ima(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_probe_ima(
    ima_file: InputPathType,
    key_string: str | None = None,
    offset_type_len: str | None = None,
    attribute_name: str | None = None,
    fileinfo: bool = False,
    dictionary: bool = False,
    ob_stem: str | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriProbeImaOutputs:
    """
    Query Siemens IMA files to extract header information.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        ima_file: Path to the IMA file to be probed.
        key_string: String from dictionary to query the IMA file.
        offset_type_len: Offset, type, and string length for querying. Type can\
            be short, int, long, float, double, or string.
        attribute_name: Name of the file information attribute to query.
        fileinfo: Dump the interpreted file information.
        dictionary: Dump the dictionary without the need of an IMA file.
        ob_stem: Dump binary pixel data into bshort with stem prefix.
        help_: Show help message and exit.
        version: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriProbeImaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_PROBE_IMA_METADATA)
    cargs = []
    cargs.append("mri_probe_ima")
    cargs.extend([
        "--i",
        execution.input_file(ima_file)
    ])
    if key_string is not None:
        cargs.extend([
            "--key",
            key_string
        ])
    if offset_type_len is not None:
        cargs.extend([
            "--o",
            offset_type_len
        ])
    if attribute_name is not None:
        cargs.extend([
            "--attr",
            attribute_name
        ])
    if fileinfo:
        cargs.append("--fileinfo")
    if dictionary:
        cargs.append("--dictionary")
    if ob_stem is not None:
        cargs.extend([
            "--ob",
            ob_stem
        ])
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MriProbeImaOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_PROBE_IMA_METADATA",
    "MriProbeImaOutputs",
    "mri_probe_ima",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PRELUDE_METADATA = Metadata(
    id="5adffe55db73f990a6bff1ef9b7c656a99d9928b.boutiques",
    name="prelude",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PreludeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `prelude(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unwrapped_phase_output: OutputPathType
    """Unwrapped phase output file"""
    saved_mask_volume: OutputPathType | None
    """Saved mask volume file"""
    saved_raw_phase_output: OutputPathType | None
    """Saved raw phase output file"""
    saved_area_labels_output: OutputPathType | None
    """Saved area labels output file"""


def prelude(
    output_unwrap: InputPathType,
    output_unwrap_alias: InputPathType,
    complex_phase: InputPathType | None = None,
    complex_phase_alias: InputPathType | None = None,
    absolute_volume: InputPathType | None = None,
    absolute_volume_alias: InputPathType | None = None,
    phase_volume: InputPathType | None = None,
    phase_volume_alias: InputPathType | None = None,
    num_phase_split: float | None = None,
    label_slices: bool = False,
    slice_processing: bool = False,
    slice_processing_alias: bool = False,
    force_3d: bool = False,
    force_3d_alias: bool = False,
    threshold: float | None = None,
    threshold_alias: float | None = None,
    mask_volume: InputPathType | None = None,
    mask_volume_alias: InputPathType | None = None,
    start_image: float | None = None,
    end_image: float | None = None,
    save_mask: InputPathType | None = None,
    save_raw_phase: InputPathType | None = None,
    save_raw_phase_alias: InputPathType | None = None,
    save_labels: InputPathType | None = None,
    save_labels_alias: InputPathType | None = None,
    remove_ramps: bool = False,
    verbose: bool = False,
    verbose_alias: bool = False,
    help_: bool = False,
    help_alias: bool = False,
    runner: Runner | None = None,
) -> PreludeOutputs:
    """
    Phase Region Expanding Labeller for Unwrapping Discrete Estimates.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        output_unwrap: Filename for saving the unwrapped phase output.
        output_unwrap_alias: Filename for saving the unwrapped phase output.
        complex_phase: Filename of complex phase input volume.
        complex_phase_alias: Filename of complex phase input volume.
        absolute_volume: Filename of absolute input volume.
        absolute_volume_alias: Filename of absolute input volume.
        phase_volume: Filename of raw phase input volume.
        phase_volume_alias: Filename of raw phase input volume.
        num_phase_split: Number of phase partitions to use.
        label_slices: Does label processing in 2D (slice at a time).
        slice_processing: Does all processing in 2D (slice at a time).
        slice_processing_alias: Does all processing in 2D (slice at a time).
        force_3d: Forces all processing to be full 3D.
        force_3d_alias: Forces all processing to be full 3D.
        threshold: Intensity threshold for masking.
        threshold_alias: Intensity threshold for masking.
        mask_volume: Filename of mask input volume.
        mask_volume_alias: Filename of mask input volume.
        start_image: First image number to process (default 0).
        end_image: Final image number to process (default Inf).
        save_mask: Filename for saving the mask volume.
        save_raw_phase: Filename for saving the raw phase output.
        save_raw_phase_alias: Filename for saving the raw phase output.
        save_labels: Filename for saving the area labels output.
        save_labels_alias: Filename for saving the area labels output.
        remove_ramps: Remove phase ramps during unwrapping.
        verbose: Switch on diagnostic messages.
        verbose_alias: Switch on diagnostic messages.
        help_: Display help message.
        help_alias: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PreludeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PRELUDE_METADATA)
    cargs = []
    cargs.append("prelude")
    cargs.extend([
        "-o",
        execution.input_file(output_unwrap)
    ])
    cargs.extend([
        "-u",
        execution.input_file(output_unwrap_alias)
    ])
    if complex_phase is not None:
        cargs.extend([
            "-c",
            execution.input_file(complex_phase)
        ])
    if complex_phase_alias is not None:
        cargs.extend([
            "--complex",
            execution.input_file(complex_phase_alias)
        ])
    if absolute_volume is not None:
        cargs.extend([
            "-a",
            execution.input_file(absolute_volume)
        ])
    if absolute_volume_alias is not None:
        cargs.extend([
            "--abs",
            execution.input_file(absolute_volume_alias)
        ])
    if phase_volume is not None:
        cargs.extend([
            "-p",
            execution.input_file(phase_volume)
        ])
    if phase_volume_alias is not None:
        cargs.extend([
            "--phase",
            execution.input_file(phase_volume_alias)
        ])
    if num_phase_split is not None:
        cargs.extend([
            "-n",
            str(num_phase_split)
        ])
    if label_slices:
        cargs.append("--labelslices")
    if slice_processing:
        cargs.append("-s")
    if slice_processing_alias:
        cargs.append("--slices")
    if force_3d:
        cargs.append("-f")
    if force_3d_alias:
        cargs.append("--force3D")
    if threshold is not None:
        cargs.extend([
            "-t",
            str(threshold)
        ])
    if threshold_alias is not None:
        cargs.extend([
            "--thresh",
            str(threshold_alias)
        ])
    if mask_volume is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_volume)
        ])
    if mask_volume_alias is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_volume_alias)
        ])
    if start_image is not None:
        cargs.extend([
            "--start",
            str(start_image)
        ])
    if end_image is not None:
        cargs.extend([
            "--end",
            str(end_image)
        ])
    if save_mask is not None:
        cargs.extend([
            "--savemask",
            execution.input_file(save_mask)
        ])
    if save_raw_phase is not None:
        cargs.extend([
            "-r",
            execution.input_file(save_raw_phase)
        ])
    if save_raw_phase_alias is not None:
        cargs.extend([
            "--rawphase",
            execution.input_file(save_raw_phase_alias)
        ])
    if save_labels is not None:
        cargs.extend([
            "-l",
            execution.input_file(save_labels)
        ])
    if save_labels_alias is not None:
        cargs.extend([
            "--labels",
            execution.input_file(save_labels_alias)
        ])
    if remove_ramps:
        cargs.append("--removeramps")
    if verbose:
        cargs.append("-v")
    if verbose_alias:
        cargs.append("--verbose")
    if help_:
        cargs.append("-h")
    if help_alias:
        cargs.append("--help")
    ret = PreludeOutputs(
        root=execution.output_file("."),
        unwrapped_phase_output=execution.output_file(pathlib.Path(output_unwrap).name + ".nii.gz"),
        saved_mask_volume=execution.output_file(pathlib.Path(save_mask).name + ".nii.gz") if (save_mask is not None) else None,
        saved_raw_phase_output=execution.output_file(pathlib.Path(save_raw_phase).name + ".nii.gz") if (save_raw_phase is not None) else None,
        saved_area_labels_output=execution.output_file(pathlib.Path(save_labels).name + ".nii.gz") if (save_labels is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PRELUDE_METADATA",
    "PreludeOutputs",
    "prelude",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_SUM_METADATA = Metadata(
    id="94da9de5b9f8766cfa66cfcd1b32542090f7970e.boutiques",
    name="possum_sum",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class PossumSumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum_sum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Sum of all input signals from processors"""


def possum_sum(
    input_signal: InputPathType,
    output_signal: InputPathType,
    num_processors: int | None = None,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> PossumSumOutputs:
    """
    Sum of output signals from multiple possum processors.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_signal: Input signal for one processor (possum output matrix).
        output_signal: Output signal: sum of all the processors (possum matrix\
            form).
        num_processors: Number of processors.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumSumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_SUM_METADATA)
    cargs = []
    cargs.append("possum_sum")
    cargs.extend([
        "-i",
        execution.input_file(input_signal)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output_signal)
    ])
    if num_processors is not None:
        cargs.extend([
            "-n",
            str(num_processors)
        ])
    if verbose_flag:
        cargs.append("-v")
    ret = PossumSumOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(output_signal).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_SUM_METADATA",
    "PossumSumOutputs",
    "possum_sum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_GEN_PRIORS_METADATA = Metadata(
    id="845d9172d4ae6f1eca3fec82fab483b9e0b7907b.boutiques",
    name="3dGenPriors",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dGenPriorsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_gen_priors(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_cprefix: OutputPathType
    """Main classification output"""
    out_pprefix: OutputPathType
    """Main probability output"""


def v_3d_gen_priors(
    sigs: InputPathType,
    tdist: InputPathType,
    cprefix: str,
    pprefix: str,
    labeltable: InputPathType,
    do: str,
    prefix: str | None = None,
    cmask: str | None = None,
    mask: str | None = None,
    mrange: list[float] | None = None,
    debug: float | None = None,
    vox_debug: str | None = None,
    vox_debug_file: str | None = None,
    uid: str | None = None,
    use_tmp: bool = False,
    no_tmp: bool = False,
    pset: str | None = None,
    cset: str | None = None,
    regroup_classes: str | None = None,
    classes: str | None = None,
    features: str | None = None,
    strict_feature_match: bool = False,
    featgroups: str | None = None,
    show_this_dist: str | None = None,
    fast: bool = False,
    slow: bool = False,
    runner: Runner | None = None,
) -> V3dGenPriorsOutputs:
    """
    Produces classification priors based on voxel signatures.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        sigs: Signatures dataset. A dataset with F features per voxel.
        tdist: Training results. This file is generated by 3dSignatures.
        cprefix: Prefix for class dataset.
        pprefix: Prefix for probability dataset.
        labeltable: Labeltable to attach to output dataset.
        do: Specify the output that this program should create.
        prefix: Specify root prefix for output volumes.
        cmask: Provide cmask expression. Voxels where expression is 0 are\
            excluded from computations.
        mask: Provide mask dataset.
        mrange: Consider MASK only for values between M0 and M1, inclusive.
        debug: Set debug level.
        vox_debug: 1D index or 3D indices (I J K) of voxel to debug.
        vox_debug_file: File in which debug information is output.
        uid: User identifier string. Used to generate names for temporary\
            files.
        use_tmp: Use temporary storage to speed up the program.
        no_tmp: Do not use temporary storage.
        pset: Reuse probability output from an earlier run.
        cset: Reuse classification output from an earlier run.
        regroup_classes: Regroup classes into parent classes. Requires naming\
            the original classes as C1.*, C2.*, etc.
        classes: Classify into these classes only.
        features: Use these features only. Otherwise, all features in the\
            signature file will be used.
        strict_feature_match: Use strict feature name matching.
        featgroups: Feature groups.
        show_this_dist: Show information obtained from the training data about\
            the distribution of DIST. Set DIST to ALL to see all distributions.
        fast: Use OpenMPized routines for faster performance.
        slow: Do not use OpenMPized routines.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dGenPriorsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_GEN_PRIORS_METADATA)
    cargs = []
    cargs.append("3dGenPriors")
    cargs.extend([
        "-sig",
        execution.input_file(sigs)
    ])
    cargs.extend([
        "-tdist",
        execution.input_file(tdist)
    ])
    cargs.extend([
        "-cprefix",
        cprefix
    ])
    cargs.extend([
        "-pprefix",
        pprefix
    ])
    cargs.extend([
        "-labeltable",
        execution.input_file(labeltable)
    ])
    cargs.extend([
        "-do",
        do
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            mask
        ])
    if mrange is not None:
        cargs.extend([
            "-mrange",
            *map(str, mrange)
        ])
    if debug is not None:
        cargs.extend([
            "-debug",
            str(debug)
        ])
    if vox_debug is not None:
        cargs.extend([
            "-vox_debug",
            vox_debug
        ])
    if vox_debug_file is not None:
        cargs.extend([
            "-vox_debug_file",
            vox_debug_file
        ])
    if uid is not None:
        cargs.extend([
            "-uid",
            uid
        ])
    if use_tmp:
        cargs.append("-use_tmp")
    if no_tmp:
        cargs.append("-no_tmp")
    if pset is not None:
        cargs.extend([
            "-pset",
            pset
        ])
    if cset is not None:
        cargs.extend([
            "-cset",
            cset
        ])
    if regroup_classes is not None:
        cargs.extend([
            "-regroup_classes",
            regroup_classes
        ])
    if classes is not None:
        cargs.extend([
            "-classes",
            classes
        ])
    if features is not None:
        cargs.extend([
            "-features",
            features
        ])
    if strict_feature_match:
        cargs.append("-strict_feature_match")
    if featgroups is not None:
        cargs.extend([
            "-featgroups",
            featgroups
        ])
    if show_this_dist is not None:
        cargs.extend([
            "-ShowThisDist",
            show_this_dist
        ])
    if fast:
        cargs.append("-fast")
    if slow:
        cargs.append("-slow")
    ret = V3dGenPriorsOutputs(
        root=execution.output_file("."),
        out_cprefix=execution.output_file(cprefix + ".nii.gz"),
        out_pprefix=execution.output_file(pprefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dGenPriorsOutputs",
    "V_3D_GEN_PRIORS_METADATA",
    "v_3d_gen_priors",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_WM_VOLUME_METADATA = Metadata(
    id="9ae7b77a7d1b48992bd6d203bed29f888cde6271.boutiques",
    name="mris_wm_volume",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisWmVolumeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_wm_volume(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_wm_volume(
    subject: str,
    hemi: str,
    subjects_dir: str | None = None,
    whitesurfname: str | None = None,
    asegname: str | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> MrisWmVolumeOutputs:
    """
    Computes the volume of the enclosed hemisphere white matter surface, ignoring
    non-white matter voxels in the aseg.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject identifier.
        hemi: Hemisphere to compute volume for (e.g., lh or rh).
        subjects_dir: The SUBJECTS_DIR where the subject data is stored.
        whitesurfname: Name of the white surface file.
        asegname: Name of the aseg file.
        verbose: Output more messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisWmVolumeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_WM_VOLUME_METADATA)
    cargs = []
    cargs.append("mris_wm_volume")
    cargs.append(subject)
    cargs.append(hemi)
    if subjects_dir is not None:
        cargs.extend([
            "-SDIR",
            subjects_dir
        ])
    if whitesurfname is not None:
        cargs.extend([
            "-white",
            whitesurfname
        ])
    if asegname is not None:
        cargs.extend([
            "-aseg",
            asegname
        ])
    if verbose:
        cargs.append("-v")
    ret = MrisWmVolumeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_WM_VOLUME_METADATA",
    "MrisWmVolumeOutputs",
    "mris_wm_volume",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_N4_BIAS_FIELD_CORRECTION_FS_METADATA = Metadata(
    id="8e3aa79a90f40d521916471804f2c3ad2b5aa209.boutiques",
    name="AntsN4BiasFieldCorrectionFs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class AntsN4BiasFieldCorrectionFsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_n4_bias_field_correction_fs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_output_file: OutputPathType
    """Corrected volume output file."""


def ants_n4_bias_field_correction_fs(
    input_file: InputPathType,
    output_file: InputPathType,
    mask_file: InputPathType | None = None,
    shrink_factor: int | None = 4,
    iterations: list[float] | None = None,
    output_dtype: str | None = "float",
    replace_zeros: str | None = None,
    runner: Runner | None = None,
) -> AntsN4BiasFieldCorrectionFsOutputs:
    """
    Runs N4 (nonparameteric, nonuniform normalization) retrospective bias correction
    on an image. This program wraps the AntsN4BiasFieldCorrection utility available
    in the ANTs package.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume file.
        output_file: Corrected output volume file.
        mask_file: Use image mask during correction.
        shrink_factor: Resample factor to decrease computation time. Default is\
            4.
        iterations: Number of resolutions and max iterations per resolution.\
            Default is `50 50 50 50`, which indicates 4 fitting levels with 50\
            iterations each.
        output_dtype: Corrected output data type. Can be float, uchar, or int.\
            Default is float.
        replace_zeros: Replace 0s with offset + scale*rand(). Values will be\
            remasked in the output if remask=1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsN4BiasFieldCorrectionFsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_N4_BIAS_FIELD_CORRECTION_FS_METADATA)
    cargs = []
    cargs.append("AntsN4BiasFieldCorrectionFs")
    cargs.extend([
        "-i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output_file)
    ])
    if mask_file is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask_file)
        ])
    if shrink_factor is not None:
        cargs.extend([
            "-s",
            str(shrink_factor)
        ])
    if iterations is not None:
        cargs.extend([
            "-t",
            *map(str, iterations)
        ])
    if output_dtype is not None:
        cargs.extend([
            "-d",
            output_dtype
        ])
    if replace_zeros is not None:
        cargs.extend([
            "-r",
            replace_zeros
        ])
    ret = AntsN4BiasFieldCorrectionFsOutputs(
        root=execution.output_file("."),
        corrected_output_file=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_N4_BIAS_FIELD_CORRECTION_FS_METADATA",
    "AntsN4BiasFieldCorrectionFsOutputs",
    "ants_n4_bias_field_correction_fs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXTRACT_SEG_WAVEFORM_METADATA = Metadata(
    id="871847f8fc6a902c317b011804ed6c2c847d8460.boutiques",
    name="extract_seg_waveform",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ExtractSegWaveformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `extract_seg_waveform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def extract_seg_waveform(
    seg_file: InputPathType,
    seg_indices: list[float],
    input_volume: InputPathType,
    reg_file: InputPathType,
    output_file: str,
    vsm_file: InputPathType | None = None,
    regheader_flag: bool = False,
    demean_flag: bool = False,
    runner: Runner | None = None,
) -> ExtractSegWaveformOutputs:
    """
    This program extracts an average waveform from an input volume where the average
    is computed over the voxels in the given segmentation indices. The input volume
    is mapped to the space of the segmentation given the registration, and if a
    voxel shift map (VSM) is supplied, it is applied simultaneously as part of the
    transform.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        seg_file: Segmentation file.
        seg_indices: Segmentation indices, one or more indices can be specified.
        input_volume: Input volume.
        reg_file: Registration file (.lta).
        output_file: Output waveform file.
        vsm_file: Voxel shift map for B0 distortion correction.
        regheader_flag: Uses the header information in the registration file.
        demean_flag: Remove mean, first, and second order trends.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExtractSegWaveformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXTRACT_SEG_WAVEFORM_METADATA)
    cargs = []
    cargs.append("extract_seg_waveform")
    cargs.extend([
        "--seg",
        execution.input_file(seg_file)
    ])
    cargs.extend([
        "--id",
        *map(str, seg_indices)
    ])
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--reg",
        execution.input_file(reg_file)
    ])
    if vsm_file is not None:
        cargs.extend([
            "--vsm",
            execution.input_file(vsm_file)
        ])
    if regheader_flag:
        cargs.append("--regheader")
    if demean_flag:
        cargs.append("--demean")
    cargs.extend([
        "--o",
        output_file
    ])
    ret = ExtractSegWaveformOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXTRACT_SEG_WAVEFORM_METADATA",
    "ExtractSegWaveformOutputs",
    "extract_seg_waveform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_MERGEPATHS_METADATA = Metadata(
    id="18bc644100dca612df1989666e60cf3a4214164c.boutiques",
    name="dmri_mergepaths",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriMergepathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_mergepaths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_mergepaths(
    input_volumes: list[InputPathType],
    output_volume: str,
    color_table: InputPathType,
    threshold: float,
    input_directory: str | None = None,
    debug: bool = False,
    check_opts: bool = False,
    runner: Runner | None = None,
) -> DmriMergepathsOutputs:
    """
    A tool for merging diffusion MRI path data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volumes: Input volume(s).
        output_volume: Output volume.
        color_table: Color table file.
        threshold: Lower threshold for display (0<=num<=1, as fraction of max).
        input_directory: Input directory (optional). If specified, names of\
            input files are relative to this.
        debug: Turn on debugging.
        check_opts: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriMergepathsOutputs`).
    """
    if not (0 <= threshold <= 1): 
        raise ValueError(f"'threshold' must be between 0 <= x <= 1 but was {threshold}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_MERGEPATHS_METADATA)
    cargs = []
    cargs.append("./dmri_mergepaths")
    cargs.extend([execution.input_file(f) for f in input_volumes])
    if input_directory is not None:
        cargs.extend([
            "--indir",
            input_directory
        ])
    cargs.extend([
        "--out",
        output_volume
    ])
    cargs.extend([
        "--ctab",
        execution.input_file(color_table)
    ])
    cargs.extend([
        "--thresh",
        str(threshold)
    ])
    if debug:
        cargs.append("--debug")
    if check_opts:
        cargs.append("--checkopts")
    ret = DmriMergepathsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_MERGEPATHS_METADATA",
    "DmriMergepathsOutputs",
    "dmri_mergepaths",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANTS_TRANSFORM_INFO_METADATA = Metadata(
    id="db110d69e8361c7a0293d1d70937a09c146e535a.boutiques",
    name="antsTransformInfo",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AntsTransformInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `ants_transform_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_info: OutputPathType
    """Information of the provided transform file."""


def ants_transform_info(
    transform_file: InputPathType,
    runner: Runner | None = None,
) -> AntsTransformInfoOutputs:
    """
    Provide information about an ITK transform file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        transform_file: The transform file to read. Supported formats include\
            HDF5, MINC, Matlab, and Txt.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AntsTransformInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANTS_TRANSFORM_INFO_METADATA)
    cargs = []
    cargs.append("antsTransformInfo")
    cargs.extend([
        "--file",
        execution.input_file(transform_file)
    ])
    ret = AntsTransformInfoOutputs(
        root=execution.output_file("."),
        output_info=execution.output_file("transform_info.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANTS_TRANSFORM_INFO_METADATA",
    "AntsTransformInfoOutputs",
    "ants_transform_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SEGHEAD_METADATA = Metadata(
    id="08340cd5e951bddba3f6bc9a63145997fab29dc1.boutiques",
    name="mri_seghead",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSegheadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_seghead(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_seghead(
    input_volume: str,
    output_volume: str,
    fill_value: float | None = None,
    fhi_value: float | None = None,
    thresh1_value: float | None = None,
    thresh2_value: float | None = None,
    threshold: float | None = None,
    nhitsmin_value: float | None = None,
    hvoldat_file: InputPathType | None = None,
    signal_behind_head: bool = False,
    rescale: bool = False,
    fill_holes_islands: bool = False,
    seed_point: list[float] | None = None,
    or_mask_file: InputPathType | None = None,
    gdiag_option: str | None = None,
    runner: Runner | None = None,
) -> MriSegheadOutputs:
    """
    Binarizes an input volume to identify the head's voxels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume identifier, e.g., T1.
        output_volume: Output volume identifier.
        fill_value: Fill value for binarizing the head (default 255).
        fhi_value: FHI value used in type change operation (default 0.999).
        thresh1_value: Threshold value for detecting the skin (e.g., 20).
        thresh2_value: Threshold value for the final binarization (e.g., 20).
        threshold: Single threshold value applied to both thresh1 and thresh2.
        nhitsmin_value: Minimum number of consecutive hits needed to identify\
            skin (default 2).
        hvoldat_file: File to write the volume of the head in mm3 to an ASCII\
            file.
        signal_behind_head: Consider signals behind the head in the\
            binarization process.
        rescale: Rescale the input when converting to uchar.
        fill_holes_islands: Fill holes and remove islands in the binary volume.
        seed_point: Seed point specified by column, row, slice for filling\
            operation.
        or_mask_file: Mask file to include voxels in the binarization process.
        gdiag_option: Optional diagnostic option for internal use.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSegheadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SEGHEAD_METADATA)
    cargs = []
    cargs.append("mri_seghead")
    cargs.extend([
        "--invol",
        input_volume
    ])
    cargs.extend([
        "--outvol",
        output_volume
    ])
    if fill_value is not None:
        cargs.extend([
            "--fill",
            str(fill_value)
        ])
    if fhi_value is not None:
        cargs.extend([
            "--fhi",
            str(fhi_value)
        ])
    if thresh1_value is not None:
        cargs.extend([
            "--thresh1",
            str(thresh1_value)
        ])
    if thresh2_value is not None:
        cargs.extend([
            "--thresh2",
            str(thresh2_value)
        ])
    if threshold is not None:
        cargs.extend([
            "--thresh",
            str(threshold)
        ])
    if nhitsmin_value is not None:
        cargs.extend([
            "--nhitsmin",
            str(nhitsmin_value)
        ])
    if hvoldat_file is not None:
        cargs.extend([
            "--hvoldat",
            execution.input_file(hvoldat_file)
        ])
    if signal_behind_head:
        cargs.append("--get-signal-behind-head")
    if rescale:
        cargs.append("--rescale")
    if fill_holes_islands:
        cargs.append("--fill-holes-islands")
    if seed_point is not None:
        cargs.extend([
            "--seed",
            *map(str, seed_point)
        ])
    if or_mask_file is not None:
        cargs.extend([
            "--or-mask",
            execution.input_file(or_mask_file)
        ])
    if gdiag_option is not None:
        cargs.extend([
            "--gdiag",
            gdiag_option
        ])
    ret = MriSegheadOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SEGHEAD_METADATA",
    "MriSegheadOutputs",
    "mri_seghead",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

XHEMI_TAL_METADATA = Metadata(
    id="75297464bbd5b47449915f4f1464c80da7860766.boutiques",
    name="xhemi-tal",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class XhemiTalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `xhemi_tal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def xhemi_tal(
    subject: str,
    runner: Runner | None = None,
) -> XhemiTalOutputs:
    """
    Computes the talairach.xfm for xhemi based on the original (unflipped)
    talairach.xfm.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject for which to compute the talairach.xfm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `XhemiTalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(XHEMI_TAL_METADATA)
    cargs = []
    cargs.append("xhemi-tal")
    cargs.extend([
        "--s",
        subject
    ])
    ret = XhemiTalOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "XHEMI_TAL_METADATA",
    "XhemiTalOutputs",
    "xhemi_tal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_LOCAL_PV_METADATA = Metadata(
    id="54b08b1e61d1a55edf0eba3e25c0aa1254ece60a.boutiques",
    name="3dLocalPV",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dLocalPvOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_local_pv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    svd_vector_result: OutputPathType | None
    """SVD vector result dataset"""
    second_principal_vector: OutputPathType | None
    """Second principal vector dataset"""
    singular_value: OutputPathType | None
    """Singular value at each voxel dataset"""


def v_3d_local_pv(
    input_dataset: InputPathType,
    mask: InputPathType | None = None,
    automask: bool = False,
    prefix: str | None = None,
    prefix2: str | None = None,
    evprefix: str | None = None,
    neighborhood: str | None = None,
    despike: bool = False,
    polort: float | None = None,
    vnorm: bool = False,
    vproj: str | None = None,
    runner: Runner | None = None,
) -> V3dLocalPvOutputs:
    """
    Computes the Singular Value Decomposition (SVD) of the time series from a
    neighborhood of each voxel in a 3D+time dataset, which serves as a smoothing
    method for the dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input time series dataset.
        mask: Restrict operations to this mask.
        automask: Create a mask from the time series dataset.
        prefix: Save SVD vector result into this new dataset [default =\
            'LocalPV'].
        prefix2: Save second principal vector into this new dataset [default =\
            don't save it].
        evprefix: Save singular value at each voxel into this dataset [default\
            = don't save].
        neighborhood: Neighborhood definition (e.g., 'SPHERE(5)', 'TOHD(7)',\
            etc.).
        despike: Remove time series spikes from input dataset.
        polort: Detrending.
        vnorm: Normalize data vectors [strongly recommended].
        vproj: Project central data time series onto local SVD vector; if\
            followed by '2', then the central data time series will be projected on\
            the 2-dimensional subspace spanned by the first 2 principal SVD\
            vectors. [default: just output principal singular vector].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dLocalPvOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_LOCAL_PV_METADATA)
    cargs = []
    cargs.append("3dLocalPV")
    cargs.append(execution.input_file(input_dataset))
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if automask:
        cargs.append("-automask")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if prefix2 is not None:
        cargs.extend([
            "-prefix2",
            prefix2
        ])
    if evprefix is not None:
        cargs.extend([
            "-evprefix",
            evprefix
        ])
    if neighborhood is not None:
        cargs.extend([
            "-nbhd",
            neighborhood
        ])
    if despike:
        cargs.append("-despike")
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if vnorm:
        cargs.append("-vnorm")
    if vproj is not None:
        cargs.extend([
            "-vproj",
            vproj
        ])
    ret = V3dLocalPvOutputs(
        root=execution.output_file("."),
        svd_vector_result=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        second_principal_vector=execution.output_file(prefix2 + ".nii.gz") if (prefix2 is not None) else None,
        singular_value=execution.output_file(evprefix + ".nii.gz") if (evprefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dLocalPvOutputs",
    "V_3D_LOCAL_PV_METADATA",
    "v_3d_local_pv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FIND_AFNI_DSET_PATH_METADATA = Metadata(
    id="f180e5877075d554456c8f3bc0bb390ac06654a3.boutiques",
    name="@FindAfniDsetPath",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFindAfniDsetPathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__find_afni_dset_path(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__find_afni_dset_path(
    dsetname: str,
    append_file: bool = False,
    full_path: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> VFindAfniDsetPathOutputs:
    """
    Searches various AFNI directories for a specified dataset and returns its path.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dsetname: Name of the dataset to search for.
        append_file: Show the file appended to (even with atlas name).
        full_path: Print full path instead of '.'.
        help_: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFindAfniDsetPathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FIND_AFNI_DSET_PATH_METADATA)
    cargs = []
    cargs.append("@FindAfniDsetPath")
    cargs.append(dsetname)
    if append_file:
        cargs.append("-append_file")
    if full_path:
        cargs.append("-full_path")
    if help_:
        cargs.append("-help")
    ret = VFindAfniDsetPathOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFindAfniDsetPathOutputs",
    "V__FIND_AFNI_DSET_PATH_METADATA",
    "v__find_afni_dset_path",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FLIRT_FSL_METADATA = Metadata(
    id="398eadb6f9dd1993cfd24de7b26c3a35c5d0f1cd.boutiques",
    name="flirt.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FlirtFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `flirt_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    registered_volume: OutputPathType | None
    """Resulting registered volume"""
    transformation_matrix: OutputPathType | None
    """Resulting transformation matrix in ASCII format"""


def flirt_fsl(
    input_volume: InputPathType,
    reference_volume: InputPathType,
    output_volume: str | None = None,
    output_matrix: str | None = None,
    initial_matrix: InputPathType | None = None,
    data_type: typing.Literal["char", "short", "int", "float", "double"] | None = None,
    cost_function: typing.Literal["mutualinfo", "corratio", "normcorr", "normmi", "leastsq", "labeldiff"] | None = "corratio",
    search_cost_function: typing.Literal["mutualinfo", "corratio", "normcorr", "normmi", "leastsq", "labeldiff"] | None = "corratio",
    use_sform_qform: bool = False,
    display_initial_matrix: bool = False,
    angle_representation: typing.Literal["quaternion", "euler"] | None = "euler",
    interpolation_method: typing.Literal["trilinear", "nearestneighbour", "sinc"] | None = "trilinear",
    sinc_width: float | None = 7,
    sinc_window: typing.Literal["rectangular", "hanning", "blackman"] | None = None,
    histogram_bins: float | None = 256,
    degrees_of_freedom: float | None = 12,
    no_resample: bool = False,
    force_scaling: bool = False,
    min_voxel_dimension: float | None = None,
    apply_transform: bool = False,
    apply_isotropic_transform: float | None = None,
    padding_size: float | None = None,
    search_range_x: list[float] | None = [-90, 90],
    search_range_y: list[float] | None = [-90, 90],
    search_range_z: list[float] | None = [-90, 90],
    no_search: bool = False,
    coarse_search_angle: float | None = 60,
    fine_search_angle: float | None = 18,
    schedule_file: InputPathType | None = None,
    reference_weight: InputPathType | None = None,
    input_weight: InputPathType | None = None,
    no_clamp: bool = False,
    no_resample_blur: bool = False,
    rigid_body_mode: bool = False,
    verbose: bool = False,
    verbose_level: float | None = 0,
    pause_stages: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> FlirtFslOutputs:
    """
    FMRIB's Linear Image Registration Tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume.
        reference_volume: Reference volume.
        output_volume: Output volume.
        output_matrix: Output matrix filename (4x4 ASCII format).
        initial_matrix: Input 4x4 affine matrix filename.
        data_type: Force output data type.
        cost_function: Cost function for registration.
        search_cost_function: Cost function for search.
        use_sform_qform: Initialize using appropriate sform or qform.
        display_initial_matrix: Display initial matrix.
        angle_representation: Set angle representation.
        interpolation_method: Interpolation method.
        sinc_width: Sinc interpolation width.
        sinc_window: Sinc interpolation window.
        histogram_bins: Number of histogram bins.
        degrees_of_freedom: Degrees of freedom.
        no_resample: Do not change input sampling.
        force_scaling: Force rescaling even for low-res images.
        min_voxel_dimension: Minimum voxel dimension for sampling (in mm).
        apply_transform: Apply transform (no optimisation), requires -init.
        apply_isotropic_transform: Apply transform with isotropic resampling.
        padding_size: Padding size for interpolation outside image.
        search_range_x: Search range for rotation around x-axis.
        search_range_y: Search range for rotation around y-axis.
        search_range_z: Search range for rotation around z-axis.
        no_search: Set all angular search ranges to 0.
        coarse_search_angle: Coarse search angle in degrees.
        fine_search_angle: Fine search angle in degrees.
        schedule_file: Custom schedule filename.
        reference_weight: Weights for reference volume.
        input_weight: Weights for input volume.
        no_clamp: Do not use intensity clamping.
        no_resample_blur: Do not use blurring on downsampling.
        rigid_body_mode: Use 2D rigid body mode (ignores dof).
        verbose: Equivalent to -verbose 1.
        verbose_level: Level of verbosity.
        pause_stages: Pause at each stage.
        version_flag: Print version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FlirtFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FLIRT_FSL_METADATA)
    cargs = []
    cargs.append("flirt")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(reference_volume))
    if output_volume is not None:
        cargs.append(output_volume)
    if output_matrix is not None:
        cargs.extend([
            "-omat",
            output_matrix
        ])
    if initial_matrix is not None:
        cargs.extend([
            "-init",
            execution.input_file(initial_matrix)
        ])
    if data_type is not None:
        cargs.extend([
            "-datatype",
            data_type
        ])
    if cost_function is not None:
        cargs.extend([
            "-cost",
            cost_function
        ])
    if search_cost_function is not None:
        cargs.extend([
            "-searchcost",
            search_cost_function
        ])
    if use_sform_qform:
        cargs.append("-usesqform")
    if display_initial_matrix:
        cargs.append("-displayinit")
    if angle_representation is not None:
        cargs.extend([
            "-anglerep",
            angle_representation
        ])
    if interpolation_method is not None:
        cargs.extend([
            "-interp",
            interpolation_method
        ])
    if sinc_width is not None:
        cargs.extend([
            "-sincwidth",
            str(sinc_width)
        ])
    if sinc_window is not None:
        cargs.extend([
            "-sincwindow",
            sinc_window
        ])
    if histogram_bins is not None:
        cargs.extend([
            "-bins",
            str(histogram_bins)
        ])
    if degrees_of_freedom is not None:
        cargs.extend([
            "-dof",
            str(degrees_of_freedom)
        ])
    if no_resample:
        cargs.append("-noresample")
    if force_scaling:
        cargs.append("-forcescaling")
    if min_voxel_dimension is not None:
        cargs.extend([
            "-minsampling",
            str(min_voxel_dimension)
        ])
    if apply_transform:
        cargs.append("-applyxfm")
    if apply_isotropic_transform is not None:
        cargs.extend([
            "-applyisoxfm",
            str(apply_isotropic_transform)
        ])
    if padding_size is not None:
        cargs.extend([
            "-paddingsize",
            str(padding_size)
        ])
    if search_range_x is not None:
        cargs.extend([
            "-searchrx",
            *map(str, search_range_x)
        ])
    if search_range_y is not None:
        cargs.extend([
            "-searchry",
            *map(str, search_range_y)
        ])
    if search_range_z is not None:
        cargs.extend([
            "-searchrz",
            *map(str, search_range_z)
        ])
    if no_search:
        cargs.append("-nosearch")
    if coarse_search_angle is not None:
        cargs.extend([
            "-coarsesearch",
            str(coarse_search_angle)
        ])
    if fine_search_angle is not None:
        cargs.extend([
            "-finesearch",
            str(fine_search_angle)
        ])
    if schedule_file is not None:
        cargs.extend([
            "-schedule",
            execution.input_file(schedule_file)
        ])
    if reference_weight is not None:
        cargs.extend([
            "-refweight",
            execution.input_file(reference_weight)
        ])
    if input_weight is not None:
        cargs.extend([
            "-inweight",
            execution.input_file(input_weight)
        ])
    if no_clamp:
        cargs.append("-noclamp")
    if no_resample_blur:
        cargs.append("-noresampblur")
    if rigid_body_mode:
        cargs.append("-2D")
    if verbose:
        cargs.append("-v")
    if verbose_level is not None:
        cargs.extend([
            "-verbose",
            str(verbose_level)
        ])
    if pause_stages:
        cargs.append("-i")
    if version_flag:
        cargs.append("-version")
    ret = FlirtFslOutputs(
        root=execution.output_file("."),
        registered_volume=execution.output_file(output_volume + ".nii") if (output_volume is not None) else None,
        transformation_matrix=execution.output_file(output_matrix) if (output_matrix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FLIRT_FSL_METADATA",
    "FlirtFslOutputs",
    "flirt_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_NOTAL_METADATA = Metadata(
    id="a7a96a3826fdc962ee75d09bc6629b89ee8c17d9.boutiques",
    name="segment_subject_notal",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectNotalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_notal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def segment_subject_notal(
    subject_path: str,
    runner: Runner | None = None,
) -> SegmentSubjectNotalOutputs:
    """
    A script to segment subjects (notal).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_path: Path to the subject's directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectNotalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_NOTAL_METADATA)
    cargs = []
    cargs.append("segment_subject_notal")
    cargs.append(subject_path)
    ret = SegmentSubjectNotalOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_NOTAL_METADATA",
    "SegmentSubjectNotalOutputs",
    "segment_subject_notal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPLIT_PARTS_GPU_METADATA = Metadata(
    id="d04fb1d28332d7da5a41bbc4ec0da2b3260458cf.boutiques",
    name="split_parts_gpu",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SplitPartsGpuOutputs(typing.NamedTuple):
    """
    Output object returned when calling `split_parts_gpu(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_parts: OutputPathType
    """Output parts files"""


def split_parts_gpu(
    datafile: InputPathType,
    maskfile: InputPathType,
    bvals_file: InputPathType,
    bvecs_file: InputPathType,
    use_grad_file: int,
    total_num_parts: int,
    output_directory: str,
    grad_file: str | None = None,
    runner: Runner | None = None,
) -> SplitPartsGpuOutputs:
    """
    Splits parts of data for GPU processing.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        datafile: Input data file.
        maskfile: Input mask file.
        bvals_file: bvals file.
        bvecs_file: bvecs file.
        use_grad_file: Use gradient file (0 or 1).
        total_num_parts: Total number of parts.
        output_directory: Output directory.
        grad_file: Gradient file (can be null).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SplitPartsGpuOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPLIT_PARTS_GPU_METADATA)
    cargs = []
    cargs.append("split_parts_gpu")
    cargs.append(execution.input_file(datafile))
    cargs.append(execution.input_file(maskfile))
    cargs.append(execution.input_file(bvals_file))
    cargs.append(execution.input_file(bvecs_file))
    if grad_file is not None:
        cargs.append(grad_file)
    cargs.append(str(use_grad_file))
    cargs.append(str(total_num_parts))
    cargs.append(output_directory)
    ret = SplitPartsGpuOutputs(
        root=execution.output_file("."),
        output_parts=execution.output_file(output_directory + "/part_*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPLIT_PARTS_GPU_METADATA",
    "SplitPartsGpuOutputs",
    "split_parts_gpu",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TEST_RECON_ALL_CSH_METADATA = Metadata(
    id="8cf72a95ce1a11314c60b7ef805c1a1b7bf68cfb.boutiques",
    name="test_recon-all.csh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TestReconAllCshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `test_recon_all_csh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    recon_all_output: OutputPathType
    """Output from the recon-all utility."""
    mri_diff_output: OutputPathType
    """Output from the mri_diff utility."""
    mri_compute_seg_overlap_output: OutputPathType
    """Output from the mri_compute_seg_overlap utility."""
    mris_diff_output: OutputPathType
    """Output from the mris_diff utility."""
    mri_surf2surf_output: OutputPathType
    """Output from the mri_surf2surf utility."""
    mris_compute_parc_overlap_output: OutputPathType
    """Output from the mris_compute_parc_overlap utility."""
    diff_output: OutputPathType
    """Output from the diff utility."""
    asegstatsdiff_output: OutputPathType
    """Output from the asegstatsdiff utility."""
    aparcstatsdiff_output: OutputPathType
    """Output from the aparcstatsdiff utility."""


def test_recon_all_csh(
    reference_subj_source_dir: str | None = "/space/freesurfer/subjects/test/weekly_test/subjects/x86_64",
    reference_subjid: str | None = "bert",
    test_subject_dest_dir: str | None = "/tmp",
    test_subjid: str | None = "bert",
    freesurfer_home: str | None = "/usr/local/freesurfer/stable",
    norecon: bool = False,
    runner: Runner | None = None,
) -> TestReconAllCshOutputs:
    """
    Script for testing recon-all and other utilities with FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        reference_subj_source_dir: Directory of the reference subject source.
        reference_subjid: ID of the reference subject.
        test_subject_dest_dir: Directory for the test subject destination.
        test_subjid: ID of the test subject.
        freesurfer_home: Path to the FreeSurfer installation directory.
        norecon: Flag to indicate that recon-all should not be run.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TestReconAllCshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TEST_RECON_ALL_CSH_METADATA)
    cargs = []
    cargs.append("test_recon-all.csh")
    if reference_subj_source_dir is not None:
        cargs.extend([
            "-rsd",
            reference_subj_source_dir
        ])
    if reference_subjid is not None:
        cargs.extend([
            "-rs",
            reference_subjid
        ])
    if test_subject_dest_dir is not None:
        cargs.extend([
            "-tsd",
            test_subject_dest_dir
        ])
    if test_subjid is not None:
        cargs.extend([
            "-ts",
            test_subjid
        ])
    if freesurfer_home is not None:
        cargs.extend([
            "-fshome",
            freesurfer_home
        ])
    if norecon:
        cargs.append("-norecon")
    ret = TestReconAllCshOutputs(
        root=execution.output_file("."),
        recon_all_output=execution.output_file("recon_all_output.txt"),
        mri_diff_output=execution.output_file("mri_diff_output.txt"),
        mri_compute_seg_overlap_output=execution.output_file("mri_compute_seg_overlap_output.txt"),
        mris_diff_output=execution.output_file("mris_diff_output.txt"),
        mri_surf2surf_output=execution.output_file("mri_surf2surf_output.txt"),
        mris_compute_parc_overlap_output=execution.output_file("mris_compute_parc_overlap_output.txt"),
        diff_output=execution.output_file("diff_output.txt"),
        asegstatsdiff_output=execution.output_file("asegstatsdiff_output.txt"),
        aparcstatsdiff_output=execution.output_file("aparcstatsdiff_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TEST_RECON_ALL_CSH_METADATA",
    "TestReconAllCshOutputs",
    "test_recon_all_csh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GCATRAINSKULL_METADATA = Metadata(
    id="89af41167df36313b39cb032d8e1c2c288ba043b.boutiques",
    name="gcatrainskull",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class GcatrainskullOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gcatrainskull(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def gcatrainskull(
    gcatrain_dir: str,
    runner: Runner | None = None,
) -> GcatrainskullOutputs:
    """
    GCA train skull stripping tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gcatrain_dir: Directory containing GCA training data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GcatrainskullOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GCATRAINSKULL_METADATA)
    cargs = []
    cargs.append("gcatrainskull")
    cargs.extend([
        "--g",
        gcatrain_dir
    ])
    ret = GcatrainskullOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GCATRAINSKULL_METADATA",
    "GcatrainskullOutputs",
    "gcatrainskull",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABELS_DISJOINT_METADATA = Metadata(
    id="0053bad0da3df3d89f08c41248c8b88f9f33fb32.boutiques",
    name="labels_disjoint",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LabelsDisjointOutputs(typing.NamedTuple):
    """
    Output object returned when calling `labels_disjoint(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Resulting output label file after subtraction."""


def labels_disjoint(
    label1: InputPathType,
    label2: InputPathType,
    outputname: str,
    runner: Runner | None = None,
) -> LabelsDisjointOutputs:
    """
    Subtracts one label file from another, effectively creating a label that
    represents label1 minus label2.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label1: First label file (e.g., rh.Occ.label).
        label2: Second label file to subtract from the first (e.g.,\
            rh.V1.label).
        outputname: Output label file name where the result will be saved\
            (e.g., rh.Occ_V1.label).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelsDisjointOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABELS_DISJOINT_METADATA)
    cargs = []
    cargs.append("labels_disjoint")
    cargs.append(execution.input_file(label1))
    cargs.append(execution.input_file(label2))
    cargs.append(outputname)
    ret = LabelsDisjointOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(outputname),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABELS_DISJOINT_METADATA",
    "LabelsDisjointOutputs",
    "labels_disjoint",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_BASED_SMOOTHING_METADATA = Metadata(
    id="0f212837e6cfdb7d79585c7f58fe041aca5a9ef1.boutiques",
    name="SurfaceBasedSmoothing",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SurfaceBasedSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_based_smoothing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    smoothed_output: OutputPathType
    """The output smoothed image."""


def surface_based_smoothing(
    image_to_smooth: InputPathType,
    sigma: float,
    surface_image: InputPathType,
    outname: str,
    num_repeats: int | None = None,
    runner: Runner | None = None,
) -> SurfaceBasedSmoothingOutputs:
    """
    Surface-based smoothing applied to ImageToSmooth using a geodesic neighbourhood
    defined by sigma and the surface image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_to_smooth: The image that needs to be smoothed.
        sigma: Geodesic neighborhood radius.
        surface_image: Assumes a label == 1 that defines the surface.
        outname: The name of the output file.
        num_repeats: Number of times the geodesic neighborhood is applied\
            repeatedly.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceBasedSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_BASED_SMOOTHING_METADATA)
    cargs = []
    cargs.append("SurfaceBasedSmoothing")
    cargs.append(execution.input_file(image_to_smooth))
    cargs.append(str(sigma))
    cargs.append(execution.input_file(surface_image))
    cargs.append(outname)
    if num_repeats is not None:
        cargs.append(str(num_repeats))
    ret = SurfaceBasedSmoothingOutputs(
        root=execution.output_file("."),
        smoothed_output=execution.output_file(outname),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_BASED_SMOOTHING_METADATA",
    "SurfaceBasedSmoothingOutputs",
    "surface_based_smoothing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LONG_MRIS_SLOPES_METADATA = Metadata(
    id="5ba2dca61a52a3d9141cc6cd000056f304bcba66.boutiques",
    name="long_mris_slopes",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class LongMrisSlopesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `long_mris_slopes(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def long_mris_slopes(
    qdec: InputPathType,
    meas: str,
    hemi: str,
    sd: str,
    do_avg: bool = False,
    do_rate: bool = False,
    do_pc1fit: bool = False,
    do_pc1: bool = False,
    do_spc: bool = False,
    do_stack: bool = False,
    do_label: bool = False,
    qcache: str | None = None,
    resid: str | None = None,
    fwhm: str | None = None,
    nosmooth: bool = False,
    time_: str | None = None,
    generic_time: bool = False,
    in_label: str | None = None,
    jac: bool = False,
    name_avg: str | None = None,
    name_rate: str | None = None,
    name_pc1fit: str | None = None,
    name_pc1: str | None = None,
    name_spc: str | None = None,
    name_resid: str | None = None,
    out_stack: str | None = None,
    out_label: str | None = None,
    isec_labels: str | None = None,
    stack_avg: str | None = None,
    stack_rate: str | None = None,
    stack_pc1fit: str | None = None,
    stack_pc1: str | None = None,
    stack_spc: str | None = None,
    stack_resid: str | None = None,
    runner: Runner | None = None,
) -> LongMrisSlopesOutputs:
    """
    Computes slope maps (e.g., of thickness) in a longitudinal study using
    FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        qdec: (REQUIRED) QDEC table file specifying the subjects and time\
            points.
        meas: (REQUIRED) The surface input measure (e.g. thickness).
        hemi: (REQUIRED) Run one hemisphere: lh or rh or both.
        sd: (REQUIRED) Full path to FreeSurfer subjects directory.
        do_avg: Compute and output the temporal average.
        do_rate: Compute and output the rate.
        do_pc1fit: Compute and output the percent change (w.r.t. tp1 from\
            linear fit).
        do_pc1: Compute and output the percent change (w.r.t. tp1).
        do_spc: Compute and output the symmetrized percent change (w.r.t.\
            temporal average).
        do_stack: Save the stacked within subject file (time series).
        do_label: Compute and output intersected cortex label.
        qcache: Create cache for QDEC (resample to subject <QCACHE>, e.g.\
            fsaverage).
        resid: Residual time point (pass 1 for tp1 etc., pass 0 for average) to\
            export.
        fwhm: Smoothing at specific FWHM (required for percent change).
        nosmooth: Do not smooth the data.
        time_: Variable name for time column variable (e.g. age) in QDEC table.
        generic_time: Time points are ordered in QDEC file, assume\
            time=1,2,3...
        in_label: Use pre-existing label for smoothing and to mask the output.
        jac: Use this flag when mapping area or volume maps to correct Jacobian.
        name_avg: Filename (without hemi ?h) to store temporal average.
        name_rate: Filename (without hemi ?h) to store rate.
        name_pc1fit: Filename (without hemi ?h) to store percent change fit.
        name_pc1: Filename (without hemi ?h) to store percent change.
        name_spc: Filename (without hemi ?h) to store symmetrized percent\
            change.
        name_resid: Filename (without hemi ?h) to store residual.
        out_stack: Filename to store stacked measure file.
        out_label: Filename to store within-subject intersected cortex labels.
        isec_labels: Intersect labels on <qtarget> (usually cortex labels).
        stack_avg: Output stacked avg maps on <qtarget>.
        stack_rate: Output stacked rate maps on <qtarget>.
        stack_pc1fit: Output stacked PC1FIT maps on <qtarget>.
        stack_pc1: Output stacked PC1 maps on <qtarget>.
        stack_spc: Output stacked SPC maps on <qtarget>.
        stack_resid: Output stacked residual maps on <qtarget>.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LongMrisSlopesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LONG_MRIS_SLOPES_METADATA)
    cargs = []
    cargs.append("long_mris_slopes")
    cargs.extend([
        "--qdec",
        execution.input_file(qdec)
    ])
    cargs.extend([
        "--meas",
        meas
    ])
    cargs.extend([
        "--hemi",
        hemi
    ])
    cargs.extend([
        "--sd",
        sd
    ])
    if do_avg:
        cargs.append("--do-avg")
    if do_rate:
        cargs.append("--do-rate")
    if do_pc1fit:
        cargs.append("--do-pc1fit")
    if do_pc1:
        cargs.append("--do-pc1")
    if do_spc:
        cargs.append("--do-spc")
    if do_stack:
        cargs.append("--do-stack")
    if do_label:
        cargs.append("--do-label")
    if qcache is not None:
        cargs.extend([
            "--qcache",
            qcache
        ])
    if resid is not None:
        cargs.extend([
            "--resid",
            resid
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            fwhm
        ])
    if nosmooth:
        cargs.append("--nosmooth")
    if time_ is not None:
        cargs.extend([
            "--time",
            time_
        ])
    if generic_time:
        cargs.append("--generic-time")
    if in_label is not None:
        cargs.extend([
            "--in-label",
            in_label
        ])
    if jac:
        cargs.append("--jac")
    if name_avg is not None:
        cargs.extend([
            "--name-avg",
            name_avg
        ])
    if name_rate is not None:
        cargs.extend([
            "--name-rate",
            name_rate
        ])
    if name_pc1fit is not None:
        cargs.extend([
            "--name-pc1fit",
            name_pc1fit
        ])
    if name_pc1 is not None:
        cargs.extend([
            "--name-pc1",
            name_pc1
        ])
    if name_spc is not None:
        cargs.extend([
            "--name-spc",
            name_spc
        ])
    if name_resid is not None:
        cargs.extend([
            "--name-resid",
            name_resid
        ])
    if out_stack is not None:
        cargs.extend([
            "--out-stack",
            out_stack
        ])
    if out_label is not None:
        cargs.extend([
            "--out-label",
            out_label
        ])
    if isec_labels is not None:
        cargs.extend([
            "--isec-labels",
            isec_labels
        ])
    if stack_avg is not None:
        cargs.extend([
            "--stack-avg",
            stack_avg
        ])
    if stack_rate is not None:
        cargs.extend([
            "--stack-rate",
            stack_rate
        ])
    if stack_pc1fit is not None:
        cargs.extend([
            "--stack-pc1fit",
            stack_pc1fit
        ])
    if stack_pc1 is not None:
        cargs.extend([
            "--stack-pc1",
            stack_pc1
        ])
    if stack_spc is not None:
        cargs.extend([
            "--stack-spc",
            stack_spc
        ])
    if stack_resid is not None:
        cargs.extend([
            "--stack-resid",
            stack_resid
        ])
    ret = LongMrisSlopesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LONG_MRIS_SLOPES_METADATA",
    "LongMrisSlopesOutputs",
    "long_mris_slopes",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MAPS2CSD_METADATA = Metadata(
    id="86fc4f48b601867360afe87e657c1be456f995cd.boutiques",
    name="mri_maps2csd",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMaps2csdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_maps2csd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_maps2csd(
    input_files: list[str],
    csd_file: str | None = None,
    pdf_file: str | None = None,
    subject_hemi_surf: str | None = None,
    thresh: float | None = None,
    sign: str | None = None,
    csd_apply_file: str | None = None,
    apply_out: str | None = None,
    subjects_dir: str | None = None,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> MriMaps2csdOutputs:
    """
    Tool to create CSD files and PDFs from input maps and apply them.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_files: Input file(s) or specify them directly on the command line.
        csd_file: Output CSD file.
        pdf_file: PDF file created from CSD.
        subject_hemi_surf: Subject name, hemisphere, and surface specification.
        thresh: Threshold for cluster-forming (-log10 scale).
        sign: Sign adjustment for threshold (+1, -1 or 0).
        csd_apply_file: Apply a CSD file to inputs, return p-value of max\
            cluster.
        apply_out:.
        subjects_dir: Subjects directory.
        debug: Turn on debugging.
        checkopts: Don't run, just check options then exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMaps2csdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MAPS2CSD_METADATA)
    cargs = []
    cargs.append("mri_maps2csd")
    cargs.extend([
        "--i",
        *input_files
    ])
    if csd_file is not None:
        cargs.extend([
            "--csd",
            csd_file
        ])
    if pdf_file is not None:
        cargs.extend([
            "--pdf",
            pdf_file
        ])
    if subject_hemi_surf is not None:
        cargs.extend([
            "--s",
            subject_hemi_surf
        ])
    if thresh is not None:
        cargs.extend([
            "--thresh",
            str(thresh)
        ])
    if sign is not None:
        cargs.extend([
            "--sign",
            sign
        ])
    if csd_apply_file is not None:
        cargs.extend([
            "--csd-apply",
            csd_apply_file
        ])
    if apply_out is not None:
        cargs.append(apply_out)
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = MriMaps2csdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MAPS2CSD_METADATA",
    "MriMaps2csdOutputs",
    "mri_maps2csd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSMOOTH_METADATA = Metadata(
    id="b237186199e1da14b990e2891bc27f1f59ceede0.boutiques",
    name="3dTsmooth",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTsmoothOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tsmooth(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset: OutputPathType | None
    """Smoothed 3D+time dataset"""


def v_3d_tsmooth(
    input_dataset: InputPathType,
    prefix: str | None = None,
    datum_type: str | None = None,
    lin_filter: bool = False,
    med_filter: bool = False,
    osf_filter: bool = False,
    lin_filter_custom: float | None = None,
    hamming: int | None = None,
    blackman: int | None = None,
    custom_filter: InputPathType | None = None,
    extend: bool = False,
    zero: bool = False,
    trend: bool = False,
    adaptive: int | None = None,
    runner: Runner | None = None,
) -> V3dTsmoothOutputs:
    """
    Smooths each voxel time series in a 3D+time dataset and produces as output a new
    3D+time dataset (e.g., lowpass filter in time).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: The input 3D+time dataset.
        prefix: Sets the prefix of the output dataset.
        datum_type: Coerce output dataset to be stored as the given type.
        lin_filter: 3 point linear filter: 0.15*a + 0.70*b + 0.15*c.
        med_filter: 3 point median filter: median(a,b,c).
        osf_filter: 3 point order statistics filter: 0.15*min(a,b,c) +\
            0.70*median(a,b,c) + 0.15*max(a,b,c).
        lin_filter_custom: 3 point linear filter with custom weight:\
            0.5*(1-m)*a + m*b + 0.5*(1-m)*c.
        hamming: Use N point Hamming window filter.
        blackman: Use N point Blackman window filter.
        custom_filter: Use custom filter with coefficients from a specified\
            file.
        extend: BEFORE: use the first value; AFTER: use the last value.
        zero: BEFORE and AFTER: use zero.
        trend: Compute a linear trend, and extrapolate BEFORE and AFTER.
        adaptive: Use adaptive mean filtering of width N (N must be odd and\
            bigger than 3).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTsmoothOutputs`).
    """
    if lin_filter_custom is not None and not (0 <= lin_filter_custom <= 1): 
        raise ValueError(f"'lin_filter_custom' must be between 0 <= x <= 1 but was {lin_filter_custom}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSMOOTH_METADATA)
    cargs = []
    cargs.append("3dTsmooth")
    cargs.append(execution.input_file(input_dataset))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if datum_type is not None:
        cargs.extend([
            "-datum",
            datum_type
        ])
    if lin_filter:
        cargs.append("-lin")
    if med_filter:
        cargs.append("-med")
    if osf_filter:
        cargs.append("-osf")
    if lin_filter_custom is not None:
        cargs.extend([
            "-3lin",
            str(lin_filter_custom)
        ])
    if hamming is not None:
        cargs.extend([
            "-hamming",
            str(hamming)
        ])
    if blackman is not None:
        cargs.extend([
            "-blackman",
            str(blackman)
        ])
    if custom_filter is not None:
        cargs.extend([
            "-custom",
            execution.input_file(custom_filter)
        ])
    if extend:
        cargs.append("-EXTEND")
    if zero:
        cargs.append("-ZERO")
    if trend:
        cargs.append("-TREND")
    if adaptive is not None:
        cargs.extend([
            "-adaptive",
            str(adaptive)
        ])
    ret = V3dTsmoothOutputs(
        root=execution.output_file("."),
        output_dataset=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTsmoothOutputs",
    "V_3D_TSMOOTH_METADATA",
    "v_3d_tsmooth",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DINFILL_METADATA = Metadata(
    id="263217e116d12496939583b1c3c4001f87f5e06c.boutiques",
    name="3dinfill",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dinfillOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dinfill(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_filled: OutputPathType | None
    """Filled volume output"""


def v_3dinfill(
    input_: InputPathType,
    prefix: str | None = None,
    niter: float | None = None,
    blend: typing.Literal["MODE", "AVG", "AUTO", "SOLID", "SOLID_CLEAN"] | None = None,
    minhits: float | None = None,
    ed: list[float] | None = None,
    mask: InputPathType | None = None,
    mask_range: list[float] | None = None,
    mrange: list[float] | None = None,
    cmask: str | None = None,
    runner: Runner | None = None,
) -> V3dinfillOutputs:
    """
    A program to fill holes in volumes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Fill volume dataset.
        prefix: Use PREF for output prefix.
        niter: Do not allow the fill function to do more than NITER passes.
        blend: Method for assigning a value to a hole.
        minhits: Criterion for considering a zero voxel to be a hole. Can only\
            be used with -blend SOLID.
        ed: Erode N times then dilate N times to get rid of hanging chunks.\
            Values filled in by this process get value V.
        mask: Provide mask dataset to select subset of input.
        mask_range: Specify the range of values to consider from mask dataset.
        mrange: Alias for -mask_range option.
        cmask: Provide cmask expression. Voxels where expression is 0 are\
            excluded from computations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dinfillOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DINFILL_METADATA)
    cargs = []
    cargs.append("3dinfill")
    cargs.extend([
        "-input",
        execution.input_file(input_)
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if niter is not None:
        cargs.extend([
            "-Niter",
            str(niter)
        ])
    if blend is not None:
        cargs.extend([
            "-blend",
            blend
        ])
    if minhits is not None:
        cargs.extend([
            "-minhits",
            str(minhits)
        ])
    if ed is not None:
        cargs.extend([
            "-ed",
            *map(str, ed)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mask_range is not None:
        cargs.extend([
            "-mask_range",
            *map(str, mask_range)
        ])
    if mrange is not None:
        cargs.extend([
            "-mrange",
            *map(str, mrange)
        ])
    if cmask is not None:
        cargs.extend([
            "-cmask",
            cmask
        ])
    ret = V3dinfillOutputs(
        root=execution.output_file("."),
        output_filled=execution.output_file(prefix + "_filled.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dinfillOutputs",
    "V_3DINFILL_METADATA",
    "v_3dinfill",
]
